@@ -156,7 +156,86 @@ regIfOrElse <- rex::rex(or(regIf, regElse))
   "is.nan" = 1,
   "is.na" = 1,
   "is.finite" = 1,
-  "is.infinite" = 1
+  "is.infinite" = 1,
+  "llikPois"=2,
+  "llikPoisDlambda"=2,
+  "llikBinom"=3,
+  "llikBinomDprob"=3,
+  "llikNbinom"=3,
+  "llikNbinomDprob"=3,
+  "llikNbinomMu"=3,
+  "llikNbinomMuDmu"=3,
+  "llikBeta"=3,
+  "llikBetaDshape1"=3,
+  "llikBetaDshape2"=3,
+  "llikT"=4,
+  "llikTDdf"=4,
+  "llikTDmean"=4,
+  "llikTDsd"=4,
+  "llikChisq"=2,
+  "llikChisqDdf"=2,
+  "llikExp"=2,
+  "llikExpDrate"=2,
+  "llikF"=3,
+  "llikFDdf1"=3,
+  "llikFDdf2"=3,
+  "llikGeom"=2,
+  "llikGeomDprob"=2,
+  "llikUnif"=3,
+  "llikUnifDalpha"=3,
+  "llikUnifDbeta"=3,
+  "llikWeibull"=3,
+  "llikWeibullDshape"=3,
+  "llikWeibullDscale"=3,
+  "llikGamma"=3,
+  "llikGammaDshape"=3,
+  "llikGammaDrate"=3,
+  "llikCauchy"=3,
+  "llikCauchyDlocation"=3,
+  "llikCauchyDscale"=3,
+  "llikNorm"=3,
+  "llikNormDmean"=3,
+  "llikNormDsd"=3,
+  # Now the llikX variety for saving comp. time
+  "llikXPois"=3,
+  "llikXPoisDlambda"=3,
+  "llikXBinom"=4,
+  "llikXBinomDprob"=4,
+  "llikXNbinomMu"=4,
+  "llikXNbinomMuDmu"=4,
+  "llikXNbinom"=4,
+  "llikXNbinomDprob"=4,
+  "llikXBeta"=4,
+  "llikXBetaDshape1"=4,
+  "llikXBetaDshape2"=4,
+  "llikXT"=5,
+  "llikXTDdf"=5,
+  "llikXTDmean"=5,
+  "llikXTDsd"=5,
+  "llikXChisq"=3,
+  "llikXChisqDdf"=3,
+  "llikXExp"=3,
+  "llikXExpDrate"=3,
+  "llikXF"=4,
+  "llikXFDdf1"=4,
+  "llikXFDdf2"=4,
+  "llikXGeom"=3,
+  "llikXGeomDprob"=3,
+  "llikXUnif"=4,
+  "llikXUnifDalpha"=4,
+  "llikXUnifDbeta"=4,
+  "llikXWeibull"=4,
+  "llikXWeibullDshape"=4,
+  "llikXWeibullDscale"=4,
+  "llikXGamma"=4,
+  "llikXGammaDshape"=4,
+  "llikXGammaDrate"=4,
+  "llikXCauchy"=4,
+  "llikXCauchyDlocation"=4,
+  "llikXCauchyDscale"=4,
+  "llikXNorm"=4,
+  "llikXNormDmean"=4,
+  "llikXNormDsd"=4
 )
 
 .rxOnly <- c(
@@ -296,6 +375,7 @@ rxRmFun <- function(name) {
   if (length(.w) == 1L) assignInMyNamespace(".rxSEeqUsr", .rxSEeqUsr[-.w])
   .w <- which(name == names(.rxCcode))
   if (length(.w) == 1L) assignInMyNamespace(".rxCcode", .rxCcode[-.w])
+  .rxD <- rxode2parse::rxode2parseD()
   if (exists(name, envir = .rxD)) rm(list = name, envir = .rxD)
   if (exists(name, envir = .symengineFs)) rm(list = name, envir = .symengineFs)
   return(invisible())
@@ -324,16 +404,13 @@ rxRmFun <- function(name) {
   "M_SQRT_PI" = "sqrt(pi)",
   "M_2_SQRTPI" = "2/sqrt(pi)",
   "M_1_SQRT_2PI" = "1/sqrt(2*pi)",
-  "M_SQRT_2" = "sqrt(2)",
+  "M_SQRT2" = "sqrt(2)",
   "M_SQRT_3" = "sqrt(3)",
   "M_SQRT_32" = "sqrt(32)",
   "M_SQRT_2dPI" = "sqrt(2/pi)",
   "M_LN_SQRT_PI" = "log(sqrt(pi))",
   "M_LN_SQRT_2PI" = "log(sqrt(2*pi))",
   "M_LN_SQRT_PId2" = "log(sqrt(pi/2))",
-  "M_SQRT2" = "sqrt(2)",
-  "M_SQRT3" = "sqrt(3)",
-  "M_SQRT32" = "sqrt(32)",
   "M_LOG10_2" = "log(2)/log(10)",
   "M_LOG2E" = "1/log(2)",
   "M_LOG10E" = "1/log(10)",
@@ -350,294 +427,6 @@ rxRmFun <- function(name) {
   "GoldenRatio" = 2.118033988749894902526,
   "I" = 1i
 )
-## diff(rxTBS(a,lambda,yj),a)
-.rxD <- new.env(parent = emptyenv())
-## This environment is a derivative table;
-## For example:
-## Derivative(f(a,b,c), a) = fa()
-## Derivative(f(a,b,c), b) = fb()
-## Derivative(f(a,b,c), c) = fc()
-## Then
-##
-## .rxD$f <- list(fa(a,b,c), fb(a,b,c), fc(a,b,c))
-##
-##  fa translates the arguments to the derivative with respect to a
-##  fb translates the arguments to the derivative with respect to b
-##
-## If any of the list is NULL then rxode2 won't know how to take a
-## derivative with respect to the argument.
-##
-## If the list is shorter than the length of the arguments then the
-## argument then the derivative of arguments that are not specified
-## cannot be taken.
-
-.rxD$atan2 <- list(
-  function(y, x) {
-    return(paste0("(", x, ")/((", x, ")^2+(", y, ")^2)"))
-  },
-  function(y, x) {
-    return(paste0("-(", y, ")/((", x, ")^2+(", y, ")^2)"))
-  }
-)
-
-.rxD$erfinv <- list(
-  function(x) {
-    ## http://specialfunctionswiki.org/index.php/Derivative_of_inverse_error_function
-    return(paste0("sqrt(pi)/2*exp((erfinv(", x, "))^2)"))
-  }
-)
-
-.rxD$abs0 <- list(function(x) {
-  return(paste0("dabs(", x, ")"))
-})
-
-.rxD$abs <- list(function(x) {
-  return(paste0("dabs(", x, ")"))
-})
-
-
-.rxD$abs1 <- list(function(x) {
-  return(paste0("dabs1(", x, ")"))
-})
-
-.rxD$dabs1 <- list(function(x) {
-  return("0")
-})
-
-.rxD$dabs <- list(function(x) {
-  return(paste0("dabs2(", x, ")"))
-})
-
-.rxD$dabs2 <- list(function(x) {
-  return("0")
-})
-
-
-.rxD$rxTBS <- list(function(a, lambda, yj, hi, low) {
-  paste0("rxTBSd(", a, ",", lambda, ",", yj, ",", hi, ",", low, ")")
-})
-
-.rxD$rxTBSd <- list(function(a, lambda, yj, hi, low) {
-  paste0("rxTBSd2(", a, ",", lambda, ",", yj, ",", hi, ",", low, ")")
-})
-
-.rxD$..k <- 10
-.rxD$..tol <- 1e-4
-## Approx a==b by
-## (1-tanh(k*(a-b))^2)
-.rxD$rxEq <- list(
-  function(a, b) {
-    .ab <- paste0("(", a, "-", b, ")")
-    return(paste0(
-      "(", -2 * .rxD$..k, "*tanh(", .rxD$..k, "*", .ab, ")+",
-      2 * .rxD$..k, "*tanh(", .rxD$..k, "*", .ab, ")^3)"
-    ))
-  }, function(a, b) {
-    .ab <- paste0("(", a, "-", b, ")")
-    return(paste0(
-      "(", 2 * .rxD$..k, "*tanh(", .rxD$..k, "*", .ab, ")-",
-      2 * .rxD$..k, "*tanh(", .rxD$..k, "*", .ab, ")^3)"
-    ))
-  }
-)
-
-.rxD$rxGeq <- list(
-  function(a, b) {
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    ## approx is (1/2+1/2*tanh(k*(a-b)-delta))
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (1/2)*k + (-1/2)*k*tanh(-delta + k*(a - b))^2
-    return(paste0(
-      "(", .rxD$..k / 2, "-", .rxD$..k / 2, "*tanh(", -.delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }, function(a, b) {
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    ## approx is (1/2+1/2*tanh(k*(a-b)-delta))
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (1/2)*k + (-1/2)*k*tanh(-delta + k*(a - b))^2
-    return(paste0(
-      "(", -.rxD$..k / 2, "+", .rxD$..k / 2, "*tanh(", -.delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }
-)
-
-.rxD$rxLeq <- list(
-  function(a, b) {
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    ## approx is (1/2-1/2*tanh(k*(a-b)+delta))
-    .ab <- paste0("(", a, "-", b, ")")
-    return(paste0(
-      "(", -.rxD$..k / 2, "+", .rxD$..k / 2, "*tanh(", .delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }, function(a, b) {
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    ## approx is (1/2-1/2*tanh(k*(a-b)+delta))
-    .ab <- paste0("(", a, "-", b, ")")
-    return(paste0(
-      "(", .rxD$..k / 2, "-", .rxD$..k / 2, "*tanh(", .delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }
-)
-
-
-.rxD$rxLt <- list(
-  function(a, b) {
-    ## Approx is 1/2-1/2*tanh(k*(a-b)-delta)
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (-1/2)*k + (1/2)*k*tanh(-delta + k*(a - b))^2
-    return(paste0(
-      "(", -.rxD$..k / 2, "+", .rxD$..k / 2, "*tanh(", -.delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  },
-  function(a, b) {
-    ## Approx is 1/2-1/2*tanh(k*(a-b)-delta)
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (-1/2)*k + (1/2)*k*tanh(-delta + k*(a - b))^2
-    return(paste0(
-      "(", .rxD$..k / 2, "-", .rxD$..k / 2, "*tanh(", -.delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }
-)
-
-
-.rxD$rxGt <- list(
-  function(a, b) {
-    ## delta <- atanh(2*tol-1);
-    ## 1/2+1/2*tanh(k*(a-b)+delta)
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (1/2)*k + (-1/2)*k*tanh(delta + k*(a - b))^2
-    return(paste0(
-      "(", .rxD$..k / 2, "-", .rxD$..k / 2, "*tanh(", .delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  },
-  function(a, b) {
-    ## delta <- atanh(2*tol-1);
-    ## 1/2+1/2*tanh(k*(a-b)+delta)
-    .delta <- atanh(2 * .rxD$..tol - 1)
-    .ab <- paste0("(", a, "-", b, ")")
-    ## (-1/2)*k + (1/2)*k*tanh(delta + k*(a - b))^2
-    return(paste0(
-      "(", -.rxD$..k / 2, "+", .rxD$..k / 2, "*tanh(", .delta,
-      "+", .rxD$..k, "*", .ab, ")^2)"
-    ))
-  }
-)
-
-.rxD$rxAnd <- list(
-  function(a, b) {
-    ## a*b
-    return(b)
-  }, function(a, b) {
-    ## a*b
-    return(a)
-  }
-)
-
-.rxD$rxOr <- list(
-  function(a, b) {
-    ## Using DeMorgan's Theorem
-    ## a+b = 1-(1-a)*(1-b)
-    return(paste0("(1-(", b, "))"))
-  }, function(a, b) {
-    return(paste0("(1-(", a, "))"))
-  }
-)
-
-
-.rxD$rxNot <- list(
-  function(a) {
-    ## 1 - a
-    return("(-1)")
-  }
-)
-
-.rxD$dose <- list(function(a) {
-  return("0")
-})
-
-.rxD$podo <- list(function(a) {
-  return("0")
-})
-
-.rxD$tlast <- list(function(a) {
-  return("0")
-})
-.rxD$tfirst <- list(function(a) {
-  return("0")
-})
-.rxD$first <- list(function(a) {
-  return("0")
-})
-.rxD$last <- list(function(a) {
-  return("0")
-})
-.rxD$diff <- list(function(a) {
-  return("0")
-})
-.rxD$is.nan <- list(function(a) {
-  return("0")
-})
-.rxD$is.na <- list(function(a) {
-  return("0")
-})
-.rxD$is.finite <- list(function(a) {
-  return("0")
-})
-.rxD$is.infinite <- list(function(a) {
-  return("0")
-})
-
-
-## Approx a>=b by
-## 1/2-1/2*tanh(k*x+delta)=1-tol
-## 1/2-1+tol=1/2*tanh(k*x+delta)
-## atanh(2*tol-1)= delta
-## 1/2-1/2*tanh(k*(a-b)+delta)
-
-.linCmtBgen <- function(i) {
-  .fun <- function(...) {}
-  body(.fun) <- bquote({
-    .args <- unlist(list(...))
-    if (.args[6] != "0") stop("cannot take a second derivative", call. = FALSE)
-    .args[6] <- .(i)
-    return(paste0("linCmtB(", paste(.args, collapse = ","), ")"))
-  })
-  return(.fun)
-}
-
-.rxD$linCmtB <- c(
-  list(
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    },
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    },
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    },
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    },
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    },
-    function(...) {
-      stop("bad 'linCmtB' derivative", call. = FALSE)
-    }
-  ),
-  lapply(1:15, .linCmtBgen)
-)
 
 #' Add to rxode2's derivative tables
 #'
@@ -669,6 +458,7 @@ rxD <- function(name, derivatives) {
   if (!all(sapply(derivatives, function(x) (inherits(x, "function") || is.null(x))))) {
     stop("derivatives must be a list of functions with at least 1 element", call. = FALSE)
   }
+  .rxD <- rxode2parse::rxode2parseD()
   if (exists(name, envir = .rxD)) {
     warning(sprintf(gettext("replacing defined derivatives for '%s'"), name), call. = FALSE)
   }
@@ -1347,8 +1137,8 @@ rxToSE <- function(x, envir = NULL, progress = FALSE,
     return(.rxToSEChoose(x, envir = envir, progress = progress, isEnv=isEnv))
   } else if (identical(x[[1]], quote(`lchoose`))) {
     return(.rxToSELchoose(x, envir = envir, progress = progress, isEnv=isEnv))
-  } else if ((identical(x[[1]], quote(`pnorm`))) |
-               (identical(x[[1]], quote(`normcdf`))) |
+  } else if ((identical(x[[1]], quote(`pnorm`))) ||
+               (identical(x[[1]], quote(`normcdf`))) ||
                (identical(x[[1]], quote(`phi`)))) {
     return(.rxToSEPnorm(x, envir = envir, progress = progress, isEnv=isEnv))
   } else if (identical(x[[1]], quote(`transit`))) {
@@ -1578,14 +1368,6 @@ rxToSE <- function(x, envir = NULL, progress = FALSE,
 .rxDelta <- (.Machine$double.eps)^(1 / 3)
 
 
-.rxD$gammap <- list(
-  NULL,
-  function(a, z) {
-    paste0("gammapDer(", a, ",", z, ")")
-  }
-)
-
-
 #' @rdname rxToSE
 #' @export
 rxFromSE <- function(x, unknownDerivatives = c("forward", "central", "error")) {
@@ -2179,7 +1961,7 @@ rxFromSE <- function(x, unknownDerivatives = c("forward", "central", "error")) {
             return("M_SQRT_3")
           }
           if (.ret == "sqrt(2)") {
-            return("M_SQRT_2")
+            return("M_SQRT2")
           }
           if (.ret == "sqrt(32)") {
             return("M_SQRT_32")
@@ -2249,6 +2031,7 @@ rxFromSE <- function(x, unknownDerivatives = c("forward", "central", "error")) {
           if (any(.fun[1] == c("lead", "lag"))) {
             return("0")
           }
+          .rxD <- rxode2parse::rxode2parseD()
           if (exists(.fun[1], envir = .rxD)) {
             .funLst <- get(.fun[1], envir = .rxD)
             if (length(.funLst) < .with) {
@@ -2364,6 +2147,7 @@ rxS <- function(x, doConst = TRUE, promoteLinSens = FALSE) {
   .env$..lhs <- NULL
   .env$..lhs0 <- NULL
   .env$..doConst <- doConst
+  .rxD <- rxode2parse::rxode2parseD()
   for (.f in c(
     ls(.rxD), "linCmtA", "linCmtB", "rxEq", "rxNeq", "rxGeq", "rxLeq", "rxLt",
     "rxGt", "rxAnd", "rxOr", "rxNot", "rxTBS", "rxTBSd", "rxTBSd2", "lag", "lead"
@@ -2639,7 +2423,7 @@ rxErrEnvF$logitNorm <- function(est, low = "0", hi = "1") {
   }
   if (!is.null(rxErrEnv.lambda)) {
     if (rxErrEnv.yj != "1") {
-      if (rxErrEnv.yj != "4" & rxErrEnv.yj != "5") {
+      if (rxErrEnv.yj != "4" && rxErrEnv.yj != "5") {
         stop("'logitNorm' cannot be used with other data transformations", call. = FALSE)
       }
     }
@@ -2700,7 +2484,7 @@ rxErrEnvF$probitNorm <- function(est, low = "0", hi = "1") {
   }
   if (!is.null(rxErrEnv.lambda)) {
     if (rxErrEnv.yj != "1") {
-      if (rxErrEnv.yj != "6" & rxErrEnv.yj != "7") {
+      if (rxErrEnv.yj != "6" &&rxErrEnv.yj != "7") {
         print(rxErrEnv.yj)
         stop("'probitNorm' cannot be used with other data transformations", call. = FALSE)
       }
@@ -2761,7 +2545,7 @@ rxErrEnvF$tbs <- function(lambda) {
     stop("'boxCox' can only be in an error function", call. = FALSE)
   }
   if (!is.null(rxErrEnv.lambda)) {
-    if (rxErrEnv.yj != "0" & rxErrEnv.lambda != "0" & rxErrEnv.lambda != "1") {
+    if (rxErrEnv.yj != "0" && rxErrEnv.lambda != "0" && rxErrEnv.lambda != "1") {
       stop("'boxCox' cannot be used with other data transformations", call. = FALSE)
     }
   }
@@ -2787,7 +2571,7 @@ rxErrEnvF$tbsYj <- function(lambda) {
     stop("'yeoJohnson' can only be in an error function", call. = FALSE)
   }
   if (!is.null(rxErrEnv.lambda)) {
-    if ((rxErrEnv.yj != "1" & rxErrEnv.yj != "4" & rxErrEnv.yj != "6")) {
+    if ((rxErrEnv.yj != "1" && rxErrEnv.yj != "4" && rxErrEnv.yj != "6")) {
       stop("'yeoJohnson' cannot be used with other data transformations", call. = FALSE)
     }
   }
@@ -2870,11 +2654,11 @@ rxErrEnvF$`return` <- function(est) {
     } else {
       .yj <- rxErrEnv.yj
     }
-    if (.yj == "0" & .lambda == "1") {
+    if (.yj == "0" && .lambda == "1") {
       .yj <- "2"
       .lambda <- "1"
     }
-    if (.yj == "0" & .lambda == "0") {
+    if (.yj == "0" && .lambda == "0") {
       .yj <- "3"
       .lambda <- "0"
     }
