@@ -1,9 +1,8 @@
 test_that("tests the internal df repetition routines", {
 
-  .rx <- loadNamespace("rxode2")
 
   expect_equal(
-    .rx$.vecDf(c(a = 1, b = 1, c = 3), 3),
+    .vecDf(c(a = 1, b = 1, c = 3), 3),
     structure(list(
       a = c(1, 1, 1),
       b = c(1, 1, 1),
@@ -13,7 +12,7 @@ test_that("tests the internal df repetition routines", {
     class = "data.frame"
     )
   )
-  expect_error(.rx$.vecDf(c(a = 1, b = 1, c = 3), 0))
+  expect_error(.vecDf(c(a = 1, b = 1, c = 3), 0))
 
   d <- 4
 
@@ -32,7 +31,7 @@ test_that("tests the internal df repetition routines", {
 
   omega <- rxRmvn(4, setNames(1:d, paste0("a", 1:d)), matL)
 
-  expand <- .rx$.cbindOme(theta, omega, 4)
+  expand <- .cbindOme(theta, omega, 4)
 
   expect_equal(expand$a, rep(theta$a, each = 4))
   expect_equal(expand$b, rep(theta$b, each = 4))
@@ -43,13 +42,13 @@ test_that("tests the internal df repetition routines", {
   expect_equal(expand$a3, omega[, "a3"])
   expect_equal(expand$a4, omega[, "a4"])
 
-  expand2 <- .rx$.cbindOme(theta, NULL, 4)
+  expand2 <- .cbindOme(theta, NULL, 4)
 
   expect_equal(expand2$a, expand$a)
   expect_equal(expand2$b, expand$b)
   expect_equal(expand2$c, expand$c)
 
-  expand3 <- .rx$.cbindOme(NULL, omega, 4)
+  expand3 <- .cbindOme(NULL, omega, 4)
 
   expect_equal(expand3$a1, expand$a1)
   expect_equal(expand3$b1, expand$b1)
