@@ -1,4 +1,18 @@
 rxTest({
+
+  test_that("bad ui", {
+    
+    f <- function() {
+      ini({
+        sd <- 1
+      })
+      model({
+        err ~ add(sd)
+      })
+    }
+    expect_error(f(), "model")
+    
+  })
   test_that("issue nlmixr#501", {
 
     nlmixr_threecmt_mm_no_add_wtcl_pdtg_kout_delay <- function() {
